@@ -1,17 +1,15 @@
 #ifndef UTILS_SOFA_SUPPORT_H
 #define UTILS_SOFA_SUPPORT_H
 
-#include <cstddef>
 #include <memory>
+#include <span>
 #include <vector>
 
-#include "alspan.h"
-
 #include "mysofa.h"
 
 
 struct MySofaDeleter {
-    void operator()(MYSOFA_HRTF *sofa) { mysofa_free(sofa); }
+    void operator()(MYSOFA_HRTF *sofa) const { mysofa_free(sofa); }
 };
 using MySofaHrtfPtr = std::unique_ptr<MYSOFA_HRTF,MySofaDeleter>;
 
@@ -27,6 +25,6 @@ struct SofaField {
 
 const char *SofaErrorStr(int err);
 
-auto GetCompatibleLayout(al::span<const float> xyzs) -> std::vector<SofaField>;
+auto GetCompatibleLayout(std::span<const float> xyzs) -> std::vector<SofaField>;
 
 #endif /* UTILS_SOFA_SUPPORT_H */
